@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Mailer.py 11573 2019-05-22 07:55:28Z Andy $
+# $Id: Mailer.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -13,7 +13,7 @@
 #
 # $Author: Andy $ (Last)
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 11573 $
+# $Revision: 11616 $
 
 import os
 import re
@@ -22,7 +22,7 @@ import mimetypes
 import time
 import threading
 
-from StringIO import StringIO
+from io import StringIO
 from datetime import datetime
 from smtplib import SMTPRecipientsRefused
 
@@ -31,7 +31,7 @@ from email.mime.text import MIMEText
 
 from django.utils import timezone
 from django.core.mail import EmailMessage, EmailMultiAlternatives
-from django.utils.encoding import smart_str, smart_unicode
+from django.utils.encoding import smart_str, smart_text
 from django.contrib.sites.models import Site
 from django.template import Context
 from django.template.loader import render_to_string
@@ -223,10 +223,10 @@ class CloudMailer(Mailer):
             return True
 
         # can't compare offset-naive and offset-aware datatimes
-        now = timezone.now()
-        if isinstance(self.newsletter.sending_date, datetime):
+        now = timezone.now() #is aware print(timezone.is_aware(now))
+        if not timezone.is_aware(self.newsletter.sending_date): 
             if self.newsletter.sending_date <= datetime.now() and \
-                (self.newsletter.status == Newsletter.WAITING):
+                (self.newsletter.status == Newsletter.WAITING):   # naive
                 return True
 
             self.logger.info(
@@ -288,12 +288,12 @@ class CloudMailer(Mailer):
         @param contact Contact instance.
         """
         uidb36, token = tokenize(contact)
-        context = Context({'contact': contact,
+        context = {'contact': contact,
                            'domain': Site.objects.get_current().domain,
                            'newsletter': self.newsletter,
-                           'uidb36': uidb36, 'token': token})
-
-        content = self.newsletter_template.render(context)
+                           'uidb36': uidb36, 'token': token}
+        _context = Context(context)
+        content = self.newsletter_template.render(_context)
         if TRACKING_LINKS:
             content = trackLinks(content, context)
 
@@ -302,7 +302,7 @@ class CloudMailer(Mailer):
             linkSite = render_to_string(
                 'newsletter/newsletter_link_site.html', context)
         else:
-            linkSite = headerContent.render(context)
+            linkSite = headerContent.render(_context)
         content = body_insertion(content, linkSite)
 
         if INCLUDE_UNSUBSCRIPTION:
@@ -311,7 +311,7 @@ class CloudMailer(Mailer):
                 unsubscription = render_to_string(
                     'newsletter/newsletter_link_unsubscribe.html', context)
             else:
-                unsubscription = footerContent.render(context)
+                unsubscription = footerContent.render(_context)
             content = body_insertion(content, unsubscription, end=True)
 
         if TRACKING_IMAGE:
@@ -319,7 +319,7 @@ class CloudMailer(Mailer):
                 'newsletter/newsletter_image_tracking.html', context)
             content = body_insertion(content, image_tracking, end=True)
 
-        return smart_unicode(content)
+        return smart_text(content)
 
     def send(self, contact):
         """
