@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10827 2018-03-11 15:11:03Z David $
+# $Id: views.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,15 +11,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-03-11 23:11:03 +0800 (週日, 11 三月 2018) $
-# $Revision: 10827 $
+# $Author: Andy $
+# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
 import re
 import time
 import json
 
-from urlparse import urljoin
+from urllib.parse import urljoin
 
 from Iuppiter.dispatch import ThreadPool
 from Iuppiter.extension.views import jsonpCallback
@@ -55,7 +55,12 @@ def _getDomain():
     domain = domain.replace(':', '-')
     return domain
 
-_domain = _getDomain()
+try:
+    _domain = _getDomain()
+except Exception as e:
+    # Migrate...?
+    print(str(e))
+    _domain = ''
 
 AWS_ACCESS_KEY_ID = settings.AWS_ACCESS_KEY_ID
 AWS_SECRET_ACCESS_KEY = settings.AWS_SECRET_ACCESS_KEY
@@ -403,7 +408,7 @@ def isBounceType(bounceType, bounceSubType):
 
 import sys
 import traceback
-from urllib import urlopen
+from urllib.request import urlopen
 
 def handleSNS(request):
     """
