@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10797 2018-03-01 02:31:02Z David $
+# $Id: __init__.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-03-01 10:31:02 +0800 (週四, 01 三月 2018) $
-# $Revision: 10797 $
+# $Author: Andy $
+# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
 import os
 import re
@@ -38,7 +38,7 @@ from Theophrastus.Utility import _slugify
 
 from Theophrastus.cloud.service import CloudService
 
-WORDS = [chr(i) for i in xrange(ord('a'), ord('a') + 26)]
+WORDS = [chr(i) for i in range(ord('a'), ord('a') + 26)]
 
 cloudSrv = CloudService.getInstance()
 
@@ -207,7 +207,7 @@ class IntegrationService(BaseService):
                         return self.getOrCreateGroup(app, g.group)
             else:
                 # Regular expression.
-                pattern = re.compile(ur'%s' % g.condition,
+                pattern = re.compile(r'%s' % g.condition,
                                      re.IGNORECASE | re.UNICODE)
                 result = pattern.search(content)
                 if result and result.group():
