@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10827 2018-03-11 15:11:03Z David $
+# $Id: __init__.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,15 +11,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-03-11 23:11:03 +0800 (週日, 11 三月 2018) $
-# $Revision: 10827 $
+# $Author: Andy $
+# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
-from django.conf.urls import url, patterns
+from django.conf.urls import url
 
 from Theophrastus.newsletter_extension import views
 
-urlpatterns = patterns('',
+urlpatterns = [
     url(r'^newsletter/header/text/$', views.getDefaultHeaderText,
         name='Theophrastus.newsletter_extension.views.getDefaultHeaderText'),
     url(r'^newsletter/footer/text/$', views.getDefaultFooterText,
@@ -28,5 +28,5 @@ urlpatterns = patterns('',
         name="Theophrastus.newsletter_extension.views.getSlugName"),
     url(r'^mailingList/get/$', views.getMailingListInfo,
         name="Theophrastus.newsletter_extension.views.getMailingListInfo"),
-)
+]
 
